@@ -1,6 +1,6 @@
 /*
  *  XMail by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999,...,2002  Davide Libenzi
+ *  Copyright (C) 1999,..,2004  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,41 +20,32 @@
  *
  */
 
-
 #ifndef _SLIST_H
 #define _SLIST_H
 
-
 #define INVALID_SLIST_PTR           0
 #define ListLinkInit(p)             ((PLISTLINK) (p))->pNext = INVALID_SLIST_PTR
 
-
-
-typedef struct s_ListLink
-{
-    struct s_ListLink *pNext;
-}               LISTLINK;
+typedef struct s_ListLink {
+	struct s_ListLink *pNext;
+} LISTLINK;
 
 typedef LISTLINK *PLISTLINK;
 
 typedef PLISTLINK HSLIST;
 
-
-
-void            ListInit(HSLIST & hList);
-void            ListAddHead(HSLIST & hList, PLISTLINK pLLink);
-void            ListAddTail(HSLIST & hList, PLISTLINK pLLink);
-PLISTLINK       ListFirst(HSLIST & hList);
-PLISTLINK       ListNext(HSLIST & hList, PLISTLINK pLLink);
-PLISTLINK       ListRemovePtr(HSLIST & hList, PLISTLINK pLLink);
-PLISTLINK       ListRemove(HSLIST & hList);
-void            ListPurgeFree(HSLIST & hList);
-void            ListPurge(HSLIST & hList);
-bool            ListIsEmpty(HSLIST & hList);
-int             ListGetCount(HSLIST & hList);
-PLISTLINK      *ListGetPointers(HSLIST & hList, int &iListCount);
-void            ListReleasePointers(PLISTLINK * pPointers);
-
-
+void ListInit(HSLIST & hList);
+void ListAddHead(HSLIST & hList, PLISTLINK pLLink);
+void ListAddTail(HSLIST & hList, PLISTLINK pLLink);
+PLISTLINK ListFirst(HSLIST & hList);
+PLISTLINK ListNext(HSLIST & hList, PLISTLINK pLLink);
+PLISTLINK ListRemovePtr(HSLIST & hList, PLISTLINK pLLink);
+PLISTLINK ListRemove(HSLIST & hList);
+void ListPurgeFree(HSLIST & hList);
+void ListPurge(HSLIST & hList);
+bool ListIsEmpty(HSLIST & hList);
+int ListGetCount(HSLIST & hList);
+PLISTLINK *ListGetPointers(HSLIST & hList, int &iListCount);
+void ListReleasePointers(PLISTLINK * pPointers);
 
 #endif
