@@ -1,6 +1,6 @@
 /*
  *  XMail by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999,...,2002  Davide Libenzi
+ *  Copyright (C) 1999,..,2004  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,21 +20,14 @@
  *
  */
 
-
 #ifndef _SVRDEFINES_H
 #define _SVRDEFINES_H
 
-
-
 ///////////////////////////////////////////////////////////////////////////////
 // Include configuration options
 ///////////////////////////////////////////////////////////////////////////////
 #include "SvrConfig.h"
 
-
-
-
-
 #define TAB_COMMENT_CHAR            '#'
 #define MAX_SMTP_ADDRESS            1024
 #define MAX_ADDR_NAME               256
@@ -43,10 +36,6 @@
 #define MAX_ACCEPT_ADDRESSES        32
 #define LOG_ROTATE_HOURS            24
 #define STD_SERVER_TIMEOUT          90
-#define SMTP_ERROR_VARNAME          "SMTP-Error"
-
-
-
-
+#define LOCAL_ADDRESS               "127.0.0.1"
 
 #endif
